==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/da.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitet",
    "Personal activity feed for %s" : "Personlige aktiviteter for %s ",
    "Your feed URL is invalid" : "Din feed-URL er ugyldg",
    "Your settings have been updated." : "Dine indstillinger er blevet opdateret.",
    "This stream will show events like additions, changes & shares" : "Dette område vil vise begivenheder som tilføjelser, ændringer & delinger",
    "There are no events for this filter" : "Der ingen aktiviteter for dette filter",
    "Activity notification" : "Notifikation om aktivitet",
    "All Activities" : "Alle aktiviteter",
    "Activities by you" : "Dine aktiviteter",
    "Activities by others" : "Andres aktiviteter",
    "\"remote user\"" : "\"ekstern bruger\"",
    "in %s" : "i %s",
    "%s and %s" : "%s og %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s og <strong class=\"tooltip\" title=\"%s\">%n mere</strong>","%s og <strong class=\"tooltip\" title=\"%s\">%n andre</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s og %n mere","%s og %n flere"],
    "Hello %s," : "Hej %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Du modtager denne e-mail, fordi der i løbet af den seneste time er sket følgende på %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Du modtager denne e-mail, fordi der i løbet af den seneste dag er sket følgende på %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Du modtager denne e-mail, fordi der i løbet af den seneste uge er sket følgende på %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* og %n flere","* og %n flere"],
    "Notifications" : "Beskeder",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "List your own actions in the stream" : "Få vist dine egne handlinger i strømmen",
    "Notify about your own actions via email" : "Giv meddelelse om egne handlinger via e-mail",
    "You need to set up your email address before you can receive notification emails." : "Du skal angive din e-mailadresse før du kan modtage notifikationer via e-mail.",
    "Send emails:" : "Send e-mails:",
    "Hourly" : "Hver time",
    "Daily" : "Dagligt",
    "Weekly" : "Ugentligt",
    "Activity feed" : "Feed med aktiviteter",
    "Enable RSS feed" : "Aktiverer RSS feed",
    "No activity yet" : "Ingen aktiviteter endnu",
    "No more events to load" : "Der er Ikke flere aktiviteter som kan indlæses",
    "Files" : "Filer"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.4.tgz: owncloud/apps/activity/l10n/da.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitet",
    "Activities" : "Aktiviteter",
    "Error loading activities" : "Fejl ved indlæsning af aktiviteter",
    "No activities" : "Ingen aktiviteter",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} og {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} og {linkStart}%n mere {linkEnd}","{parameterList} og {linkStart}%n mere {linkEnd}"],
    "in {directory}" : "i {directory}",
    "This stream will show events like additions, changes & shares" : "Dette område vil vise begivenheder som tilføjelser, ændringer & delinger",
    "There are no events for this filter" : "Der ingen aktiviteter for dette filter",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "Personal activity feed for %s" : "Personlige aktiviteter for %s ",
    "Your feed URL is invalid" : "Din feed-URL er ugyldg",
    "Your settings have been updated." : "Dine indstillinger er blevet opdateret.",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "\"remote user\"" : "\"ekstern bruger\"",
    "Activity notification" : "Notifikation om aktivitet",
    "All Activities" : "Alle aktiviteter",
    "Activities by you" : "Dine aktiviteter",
    "Activities by others" : "Andres aktiviteter",
    "%s and %s" : "%s og %s",
    "Hello %s," : "Hej %s,",
    "You are receiving this email because the following things happened at %s" : "Du modtager denne email fordi følgende ting er opstået ved %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* og %n flere","* og %n flere"],
    "Notify about your own actions via email" : "Giv meddelelse om egne handlinger via e-mail",
    "You need to set up your email address before you can receive notification emails." : "Du skal angive din e-mailadresse før du kan modtage notifikationer via e-mail.",
    "Send emails:" : "Send e-mails:",
    "Hourly" : "Hver time",
    "Daily" : "Dagligt",
    "Weekly" : "Ugentligt",
    "Activity feed" : "Feed med aktiviteter",
    "Enable RSS feed" : "Aktiverer RSS feed",
    "No activity yet" : "Ingen aktiviteter endnu",
    "No more events to load" : "Der er Ikke flere aktiviteter som kan indlæses",
    "Files" : "Filer"
},
"nplurals=2; plural=(n != 1);");
